@@ -18,7 +18,7 @@ epmc_ftxt_book <- function(ext_id = NULL) {
     stop("Please provide an id. All book full texts are accessible either by the
          PMID or the 'NBK' book number")
   # call api
-  req <- httr::GET(base_uri(), path = paste(rest_path(), ext_id,
+  req <- httr::RETRY("GET", base_uri(), path = paste(rest_path(), ext_id,
     "bookXML", sep = "/"))
   # check for http status
   httr::stop_for_status(req)
