@@ -16,7 +16,13 @@
 epmc_hits <- function(query = NULL, ...) {
   # check
   query <- transform_query(query)
-  path = paste0(rest_path(), "/search")
-  doc <- rebi_GET(path, query = list(query = query, format = "json", resulttype = "idlist"))
+  path <- paste0(rest_path(), "/search")
+  doc <-
+    rebi_GET(path,
+             query = list(
+               query = query,
+               format = "json",
+               resulttype = "idlist"
+             ))
   doc$hitCount
 }
