@@ -7,6 +7,9 @@ base_uri <- function()
 # rest path
 rest_path <- function()
   "europepmc/webservices/rest"
+# annotations API
+anno_path <- function()
+  "europepmc/annotations_api"
 
 # set user agent
 ua <- httr::user_agent("https://github.com/ropensci/europepmc")
@@ -14,7 +17,7 @@ ua <- httr::user_agent("https://github.com/ropensci/europepmc")
 # check data sources
 supported_data_src <-
   c("agr", "cba", "ctx", "eth", "hir", "med", "pat",
-    "pmc")
+    "pmc", "ppr")
 
 # default batch size
 batch_size <- function()
@@ -28,11 +31,12 @@ rebi_GET <- function(path = NULL, query = NULL, ...) {
   if (is.null(path) && is.null(query))
     stop("Nothing to search")
   # call api, decode workaround because Europe PMC only accepts decoded cursor
-  req <- rGET(urltools::url_decode(
+  req <- httr::RETRY("GET", urltools::url_decode(
     httr::modify_url(
     base_uri(), path = path, query = query
     )
-  ), ua)#, httr::verbose())
+  ), #httr::verbose(),
+  ua)
   # check for http status
   httr::stop_for_status(req)
   # load json into r
@@ -109,44 +113,6 @@ transform_query <- function(query = NULL) {
   return(query)
 }
 
-
-# There is a problem with accidental internal server error (HTTP 500),
-# which, for instance, leads to CRAN checks warnings when trying to build
-# the package. Let's try and re-use googlesheets' approach:
-# https://github.com/jennybc/googlesheets/issues/225
-# https://github.com/jennybc/googlesheets/commit/a91403ecb8ab5d8059bf14a9f9878ab68a829f0a
-
-## http://www.iana.org/assignments/http-status-codes/http-status-codes-1.csv
-coarsen_code <- function(code)
-  cut(code, c(0, 500, 600), right = FALSE, labels = FALSE)
-
-VERB_n <- function(VERB, n = 5) {
-  function(...) {
-    for (i in seq_len(n)) {
-      out <- VERB(...)
-      status <- httr::status_code(out)
-      switch(coarsen_code(status),
-             break, ## < 500
-             {
-               ## >= 500
-               backoff <-
-                 stats::runif(n = 1,
-                              min = 0,
-                              max = 2 ^ i - 1)
-               ## TO DO: honor a verbose argument or option
-               mess <- paste("HTTP error %s on attempt %d ...\n",
-                             "  backing off %0.2f seconds, retrying")
-               mpf(mess, status, i, backoff)
-               Sys.sleep(backoff)
-             })
-    }
-    out
-  }
-}
-mpf <- function(...)
-  message(sprintf(...))
-rGET <- VERB_n(httr::GET)
-
 #' Progress bar definition
 #'
 #' @param limit maximum number of hits to be returned
